Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4663)

Unified Diff: chrome/service/service_process.cc

Issue 9187023: Convert use of int ms to TimeDelta in files owned by ajwong. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Remove static class instance initialization. Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/service/cloud_print/print_system_cups.cc ('k') | jingle/glue/thread_wrapper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/service/service_process.cc
diff --git a/chrome/service/service_process.cc b/chrome/service/service_process.cc
index d66e0f09494ded9c3205de715db013f57deb11d8..bf8e8f7144d412429818214d3427c7b3a1f1f203 100644
--- a/chrome/service/service_process.cc
+++ b/chrome/service/service_process.cc
@@ -43,9 +43,9 @@ ServiceProcess* g_service_process = NULL;
namespace {
// Delay in millseconds after the last service is disabled before we attempt
// a shutdown.
-const int64 kShutdownDelay = 60000;
+const int kShutdownDelaySeconds = 60;
// Delay in milliseconds between launching a browser process to check the
// policy for us. 8 hours * 60 * 60 * 1000
@@ -356,7 +356,7 @@ void ServiceProcess::ScheduleShutdownCheck() {
MessageLoop::current()->PostDelayedTask(
FROM_HERE,
base::Bind(&ServiceProcess::ShutdownIfNeeded, base::Unretained(this)),
- kShutdownDelay);
+ base::TimeDelta::FromSeconds(kShutdownDelaySeconds));
}
void ServiceProcess::ShutdownIfNeeded() {
« no previous file with comments | « chrome/service/cloud_print/print_system_cups.cc ('k') | jingle/glue/thread_wrapper.cc » ('j') | no next file with comments »
@@ -43,9 +43,9 @@ ServiceProcess* g_service_process = NULL;
namespace {
-// Delay in millseconds after the last service is disabled before we attempt
+// Delay in seconds after the last service is disabled before we attempt
// a shutdown.

Powered by Google App Engine
This is Rietveld 408576698